The Holland Computing Center (HCC) provides high-performance computing resources for Universities and Colleges in the state of Nebraska. HCC supports both research and creative, and class activity.
 
This guide provides a list of useful links for classes utilizing HCC resources.

## Useful links for instructors
- Class group creation [form](https://hcc.unl.edu/new-group-request).
- Class group renewal [form](https://hcc.unl.edu/class-renewal-request).
- Link to HCC class [policy page](https://hcc.unl.edu/hcc-policies#class-groups)

## Useful notes for instructors
- Some class may utilize custom conda environments. Some conda environments, especially the GPU-based ones, can be very large and can easily exceed the available $HOME quotas of 20GBs. To avoid this, we recommend creating group-level custom conda environment. If you are interested in this, please email hcc-support@unl.edu for further information.
- If data needs to be shared among all class members, please see https://hcc.unl.edu/docs/handling_data/swan_data_sharing/#using-group-level-shared-directory for best practices. 
- You can request HCC training/presentation [in-class](https://hcc.unl.edu/docs/faq/#can-hcc-provide-training-for-my-group).
- Creating and setting HCC accounts takes some time. To motivate students to create HCC accounts before the training/assignments are due, some professors make this process a graded assignment.


## Useful links for students
### Account creation and setup
- New user account [form](https://hcc.unl.edu/new-user-request/).
- If you already have existing HCC account, use the Supplementary Group request [form](https://hcc.unl.edu/group-addchange-request) instead.
- How to activate HCC [Duo](https://hcc.unl.edu/docs/accounts/setting_up_and_using_duo/).
- How to reset your HCC [password](https://hcc.unl.edu/docs/accounts/how_to_change_your_password/).
- What are HCC [good practices](https://hcc.unl.edu/docs/good_hcc_practices/)?
### Application links
- HCC Open OnDemand (OOD) [web access to Swan](https://swan-ood.unl.edu/).
- Detailed HCC Open OnDemand [guide](https://hcc.unl.edu/docs/open_ondemand/).
- Creating custom CPU/GPU conda [envs] (https://hcc.unl.edu/docs/applications/user_software/using_anaconda_package_manager/#creating-custom-anaconda-environments).
- For various SLURM examples of applications that run on Swan, please this [this repo](https://github.com/unlhcc/job-examples/).
- How to share [data](https://hcc.unl.edu/docs/handling_data/swan_data_sharing/) across group members.
### Training
- [HCC Info Sheet](https://go.unl.edu/hcc_info_sheet)
- [HCC SLURM Scheduler Cheat Sheet](https://go.unl.edu/hcc_slurm_cheatsheet)
- Conda user [cheat sheet](https://hcc.unl.edu/docs/attachments/11635089.pdf).
- YouTube videos of previous HCC [training events](https://www.youtube.com/@hollandcomputingcenter8962).
### Support
- For issues related to classwork or assignment please contact your TA.
- For general HCC issues, please first check the [FAQ page](https://hcc.unl.edu/docs/faq/).
- For issues with HCC resources (e.g., unavailable resources, sudden errors and job failures), contact [HCC support](mailto:hcc-support@unl.edu.). Please note that non-critical tickets/issues will be addressed during business hours (Monday through Friday, 9am-5pm CST).

## Useful notes for students
- The login node is shared among all users and it should be used only for light tasks, and not for running computationally intensive tasks. For any CPU or memory intensive operations, such as testing and running applications, one should use an [interactive session](https://hcc.unl.edu/docs/submitting_jobs/creating_an_interactive_job/), or [submit a job to the batch queue](https://hcc.unl.edu/docs/submitting_jobs/). 
- If the Open OnDemand resources are not enough, you can run JupyterLab Notebooks within [SLURM job](https://hcc.unl.edu/docs/applications/submitting_jupyter_code/running_jupyter_lab_code).
- Custom conda environments are created in $HOME by default. You can change the location of the [conda environment](https://hcc.unl.edu/docs/applications/user_software/using_anaconda_package_manager/#using-common-for-environments/).
- Custom conda environments can easily fill the 20GBs quota on $HOME. To clean space, you can [remove unused Anaconda packages and caches](https://hcc.unl.edu/docs/applications/user_software/using_anaconda_package_manager/#remove-unused-anaconda-packages-and-caches).
- If you are not sure if the storage utilization is causing issues for you, you can run [ncdu](https://hcc.unl.edu/docs/faq/#how-can-i-check-which-directories-utilize-the-most-storage-on-swan) from the Swan terminal with the location in question.