+++
title = "Formatting and mounting a volume in Linux"
description = "How to format and mount volume as a hard drive in Linux."
+++

{{% notice info %}}
This guide assumes you associated your SSH Key Pair with the instance
when it was created, and that you are connected to the [Anvil VPN]({{< relref "connecting_to_the_anvil_vpn" >}}).
{{% /notice %}}

Once you have [created and attached]({{< relref "creating_and_attaching_a_volume" >}})
your volume, it must be formatted and mounted in your Linux instance to be usable.  This
procedure is identical to what would be done when attaching a second
hard drive to a physical machine.  In this example, a 1GB volume was
created and attached to the instance.  Note that the majority of this
guide is for a newly created volume.  


{{% notice note %}}
**If you are attaching an existing volume with data already on it,
skip to [creating a directory and mounting the volume](#mounting-the-volume).**
{{% /notice %}}

#### Formatting the volume

Follow the relevant guide
([Windows]({{< relref "connecting_to_linux_instances_from_windows">}})
| [Mac]({{< relref "connecting_to_linux_instances_from_mac" >}})) for your
operating system to connect to your instance.  Formatting and mounting
the volume requires root privileges, so first run the
command `sudo su -` to get a root shell.

{{% panel theme="danger" header="**Running commands as root**" %}}**Extreme care should be taken when running commands as `root.`** It is very easy to permanently delete data or cause irreparable damage to your instance.{{% /panel %}}

{{< figure src="/images/anvil-volumes/1-sudo.png" width="576" >}}

Next, you will need to determine what device the volume is presented as
within Linux.  Typically this will be `/dev/vdb`, but it is necessary to
verify this to avoid mistakes, especially if you have more than one
volume attached to an instance.  The command `lsblk` will list the
hard drive devices and partitions.

{{< figure src="/images//anvil-volumes/2-lsblk.png" width="576" >}}

Here there is a completely empty (no partitions) disk device matching
the 1GB size of the volume, so `/dev/vdb` is the correct device.
The `parted` utility will first be used to label the device and then create a partition.

{{< highlight bash >}}
parted /dev/vdb mklabel gpt
parted /dev/vdb mkpart primary 0% 100%
{{< /highlight >}}

{{< figure src="/images/anvil-volumes/3-mkpart.png" width="576" >}}

Now that a partition has been created, it can be formatted.  Here, the
ext4 filesystem will be used.  This is the default filesystem used by
many Linux distributions including CentOS and Ubuntu, and is a good
general choice.  An alternate filesystem may be used by running a
different format command.  To format the partition using ext4, run the
command `mkfs.ext4 /dev/vdb1`.  You will see a progress message and then
be returned to the shell prompt.

{{< figure src="/images/anvil-volumes/4-mkfs.png" width="576" >}}

#### Mounting the volume

{{% notice note %}}
If you are attaching a pre-existing volume, start here.
{{% /notice %}}

Finally, the formatted partition must be mounted as a directory to be
used.  By convention this is done under `/mnt`, but you may choose to
mount it elsewhere depending on the usage.  Here, a directory
called `myvolume` will be created and the volume mounted there.  Run the
following commands to make the directory and mount the volume:

{{< highlight bash >}}
mkdir /mnt/myvolume
mount /dev/vdb1 /mnt/myvolume
{{< /highlight >}}

{{< figure src="/images/anvil-volumes/5-mount.png" width="576" >}}

Running the command `df -h` should then show the new mounted empty
volume.  

{{< figure src="/images/anvil-volumes/6-df.png" width="576" >}}

The volume can now be used.
