+++
title = "Running Paraview"
description = "How to run Paraview on HCC resources."
+++

[Paraview](https://www.paraview.org/) is an open-source, multi-platform data analysis and visualization application.
Paraview can run as a client (GUI) only, or can run as a client-server model, utilizing a MPI-based server process
for extra computational power.
This document provides the steps to run ParaView on HCC resources in both client-only mode and client-server mode.

### Running the ParaView client on HCC clusters

The ParaView GUI client can be ran from the [OpenOnDemand Desktop App]({{< relref "../../open_ondemand/virtual_desktop_and_interactive_apps" >}}). 
After the Desktop App has launched, the ParaView client can be started by using the terminal to load the ParaView module and start the application. 

```Bash
module purge
module load paraview
paraview
```

{{< figure src="/images/ParaView/paraview_client_terminal.png" height="450" >}}

Once the ParaView application has started, it can be used similar to a locally installed version of ParaView to visualize data and results.

{{< figure src="/images/ParaView/paraview_client_launched.png" height="450" >}}

### Running Paraview with extra resources

If you want to use additional resources beyond those available through an Open Ondemand application, you can run a ParaView server as a SLURM job and connect the ParaView client running in OpenOnDemand to the ParaView server. 

To help facilitate this, a headless build of ParaView has been installed on Swan, which can be used to provide extra computational resources the GUI session.
To start the MPI server process on Swan, you can use the following submit script as an example:

```Bash
#!/bin/bash
#SBATCH --name=paraview-headless
#SBATCH --ntasks=16
#SBATCH --mem-per-cpu=1024
#SBATCH --time=03:15:00
#SBATCH --error=paraview.%J.err
#SBATCH --output=paraview.%J.out

module purge
module load compiler/gcc/11 openmpi/4.1 python/3.9 paraview-headless/5.10
PORT=$(shuf -i 10000-50000 -n 1)
mpirun pvserver -p $PORT
```

The `PORT=$(shuf -i 10000-50000 -n 1)` is important to help avoid starting the ParaView server on an already used networking port. Once the server job starts, it will print out the host and port to connect on in the 'paraview.out' file.  

##### Example output:
```
Waiting for client...
Connection URL: cs://c1517.swan.hcc.unl.edu:41031
Accepting connection(s): c1517.swan.hcc.unl.edu:41031
```
{{% panel theme="warning" header="**Configuration will need done every time**" %}} Once your ParaView server job has finished, the connection details will change the next time you want to run the ParaView server. When you start the new server job, only the first section of the hostname and port will need to be changed.  Click "Connect" then.{{% /panel %}}
The hostname and port is listed on the `Accepting connection(s)` line and are used in the GUI client to connect to the server process.

To connect to the server process, choose "File" > "Connect", then "Add Server".

{{< figure src="/images/ParaView/paraview_connect_add_server.png" height="450" >}}

Fill in the information using the hostname and port previously.  Using the example above, the dialog would look like

{{< figure src="/images/ParaView/paraview_server_config.png" height="450" >}}


Click "Configure", then do "Manual Launch" on the next screen, and then save. 
{{< figure src="/images/ParaView/paraview_manual_server.png" height="450" >}}
Once the configuration has been saved, it should return to the previous dialog and you can click "Connect" to have the client use the ParaView server running in a slurm job from earlier.
{{< figure src="/images/ParaView/paraview_server_connect.png" height="450" >}}
To verify you're connected, you can show the Memory Inspector by doing "View" -> "Memory Inspector".  It should show both your client GUI and the server processes.
{{< figure src="/images/ParaView/paraview_server_memory.png" height="450" >}}







