+++
title = "Installing Perl modules"
description = "How to install needed Perl modules under your account."
weight=90
+++

If you need additional Perl modules, they can be installed into your
home directory.  We recommend using
[Anaconda](https://store.continuum.io/cshop/anaconda) to
create an environment with a self-contained, independent Perl install.
This will eliminate any conflicts from the system Perl version and
allow modules to be installed via `cpan` or `cpanminus`.

### Create an environment with Perl installed

The following commands will create an environment called `myperl`, with
Perl and cpanminus installed.

{{% panel theme="info" header="Create myperl environment" %}}
{{< highlight bash >}}
module load anaconda
conda create -n myperl perl perl-app-cpanminus
{{< /highlight >}}
{{% /panel %}}

### Activate the environment

To use the environment, it must be *activated.*

{{% panel theme="warning" header="Job submission" %}}
To use your created environment and installed modules in a SLURM job,
the following lines must be included ahead of running any Perl program.
{{% /panel %}}

{{% panel theme="info" header="Activate environment" %}}
{{< highlight bash >}}
module load anaconda
source activate myperl
{{< /highlight >}}
{{% /panel %}}

### Installing a module from CPAN

Once the environment is activated, modules can be installed via
`cpan` or `cpanm` with no special configuration needed.

{{% panel theme="info" header="Install a module" %}}
{{< highlight bash >}}
cpanm My::Module
{{< /highlight >}}
{{% /panel %}}
