+++
title = "Running Velvet with Single-End Data"
description =  "How to run velvet with single-end data on HCC resources"
weight = "10"
+++


## Running Velvet with Single-End short fasta data with k-mer=31, 8 CPUs and 100GB of RAM

The first step of running Velvet is to run **velveth**:
{{% panel header="`velveth.submit`"%}}
{{< highlight bash >}}
#!/bin/bash
#SBATCH --job-name=Velvet_Velveth
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=8
#SBATCH --time=168:00:00
#SBATCH --mem=10gb
#SBATCH --output=Velveth.%J.out
#SBATCH --error=Velveth.%J.err

module load velvet/1.2
export OMP_NUM_THREADS=$SLURM_NTASKS_PER_NODE

velveth output_directory/ 31 -fasta -short input_reads.fasta
{{< /highlight >}}
{{% /panel %}}


After running **velveth**, the next step is to run **velvetg** on the `output_directory/` and files generated from **velveth**:
{{% panel header="`velvetg.submit`"%}}
{{< highlight bash >}}
#!/bin/bash
#SBATCH --job-name=Velvet_Velvetg
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=8
#SBATCH --time=168:00:00
#SBATCH --mem=100gb
#SBATCH --output=Velvetg.%J.out
#SBATCH --error=Velvetg.%J.err

module load velvet/1.2
export OMP_NUM_THREADS=$SLURM_NTASKS_PER_NODE

velvetg output_directory/ -min_contig_lgth 200
{{< /highlight >}}
{{% /panel %}}

Both **velveth** and **velvetg** are multi-threaded.


### Velvet Output

{{% panel header="`Output directory after velveth`"%}}
{{< highlight bash >}}
$ ls output_directory/
Log  Roadmaps  Sequences
{{< /highlight >}}
{{% /panel %}}

{{% panel header="`Output directory after velvetg`"%}}
{{< highlight bash >}}
$ ls output_directory/
contigs.fa  Graph  LastGraph  Log  PreGraph  Roadmaps  Sequences  stats.txt
{{< /highlight >}}
{{% /panel %}}

The output fasta file `contigs.fa` is the final Velvet output that contains the assembled contigs. More information about the output files is provided in the Velvet manual.
